pub trait VestInput: View<V = Seq<u8>> {
// Required methods
exec fn len(&self) -> res : usize;
exec fn subrange(&self, i: usize, j: usize) -> res : Self
where Self: Sized;
exec fn clone(&self) -> res : Self
where Self: Sized;
}Expand description
Trait definitions
Trait for types that can be used as input for Vest parsers, roughly corresponding to byte buffers.
VestInput does not expose the contents of the buffer, so opaque buffer types for side-channel
security can implement VestInput.